Absorb the Flesh, Abandon the Mind Lafayette, Louisiana March 27th 2004 12 players Chad Brinkley Rome Is Burning Crypt (12 cards, min=14, max=27, avg=5.33) ------------------------------------------ 2x Korah 7 AUS DEM OBF ani priscus Malkavian antitribu:2 2x Dolphin Black 6 AUS DEM OBF Malkavian antitribu:2 2x Yorik 3 dem obf Malkavian antitribu:2 1x Kite 7 AUS DEM obf pre bishop Malkavian antitribu:2 1x Artemis 6 DEM OBF aus cel for Malkavian antitribu:2 1x Tony 6 AUS DEM dom obf Malkavian:3 1x Persia, The Beautiful Statue 5 DEM aus obf Malkavian:3 1x Adelaide Davis 4 aus dem obf Malkavian:3 1x Claven 4 aus dem obf Malkavian antitribu:2 Library (74 cards) Master (11) 1x Auspex 1x Barrens, The 4x Blood Doll 1x Institution Hunting Ground 1x Obfuscate 2x Sudden Reversal 1x Vox Domini Action (13) 2x Call, The 8x Kindred Spirits 1x Madman's Quill 2x Pulse of the Canaille Equipment (2) 1x Changeling Skin Mask 1x Enchanted Marionette Action Modifier (27) 5x Confusion 3x Elder Impersonation 5x Eyes of Chaos 3x Faceless Night 4x Lost in Crowds 3x Spying Mission 4x Walk through Arcadia Action Modifier/Combat (3) 3x Swallowed by the Night Reaction (12) 2x Delaying Tactics 6x Telepathic Misdirection 4x Wake with Evening's Freshness Combat (6) 6x Gemini's Mirror